# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.1.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

"""
TopOpeBRepTool module, see official documentation at
https://www.opencascade.com/doc/occt-7.7.0/refman/html/package_topopebreptool.html
"""

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _TopOpeBRepTool
else:
    import _TopOpeBRepTool

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _TopOpeBRepTool.delete_SwigPyIterator

    def value(self):
        return _TopOpeBRepTool.SwigPyIterator_value(self)

    def incr(self, n=1):
        return _TopOpeBRepTool.SwigPyIterator_incr(self, n)

    def decr(self, n=1):
        return _TopOpeBRepTool.SwigPyIterator_decr(self, n)

    def distance(self, x):
        return _TopOpeBRepTool.SwigPyIterator_distance(self, x)

    def equal(self, x):
        return _TopOpeBRepTool.SwigPyIterator_equal(self, x)

    def copy(self):
        return _TopOpeBRepTool.SwigPyIterator_copy(self)

    def next(self):
        return _TopOpeBRepTool.SwigPyIterator_next(self)

    def __next__(self):
        return _TopOpeBRepTool.SwigPyIterator___next__(self)

    def previous(self):
        return _TopOpeBRepTool.SwigPyIterator_previous(self)

    def advance(self, n):
        return _TopOpeBRepTool.SwigPyIterator_advance(self, n)

    def __eq__(self, x):
        return _TopOpeBRepTool.SwigPyIterator___eq__(self, x)

    def __ne__(self, x):
        return _TopOpeBRepTool.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n):
        return _TopOpeBRepTool.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n):
        return _TopOpeBRepTool.SwigPyIterator___isub__(self, n)

    def __add__(self, n):
        return _TopOpeBRepTool.SwigPyIterator___add__(self, n)

    def __sub__(self, *args):
        return _TopOpeBRepTool.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _TopOpeBRepTool:
_TopOpeBRepTool.SwigPyIterator_swigregister(SwigPyIterator)

def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error, method_name, class_name):
    return _TopOpeBRepTool.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.BRepClass3d
import OCC.Core.TopoDS
import OCC.Core.Message
import OCC.Core.TCollection
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.IntCurveSurface
import OCC.Core.math
import OCC.Core.Adaptor3d
import OCC.Core.Geom
import OCC.Core.GeomAbs
import OCC.Core.TColgp
import OCC.Core.Adaptor2d
import OCC.Core.Geom2d
import OCC.Core.Intf
import OCC.Core.Bnd
import OCC.Core.BVH
import OCC.Core.IntSurf
import OCC.Core.TopTools
import OCC.Core.IntCurvesFace
import OCC.Core.BRepAdaptor
import OCC.Core.GeomAdaptor
import OCC.Core.Geom2dAdaptor
import OCC.Core.TopExp
import OCC.Core.Extrema

from enum import IntEnum
from OCC.Core.Exception import *

TopOpeBRepTool_BSPLINE1 = _TopOpeBRepTool.TopOpeBRepTool_BSPLINE1
TopOpeBRepTool_APPROX = _TopOpeBRepTool.TopOpeBRepTool_APPROX
TopOpeBRepTool_INTERPOL = _TopOpeBRepTool.TopOpeBRepTool_INTERPOL


class TopOpeBRepTool_OutCurveType(IntEnum):
	TopOpeBRepTool_BSPLINE1 = 0
	TopOpeBRepTool_APPROX = 1
	TopOpeBRepTool_INTERPOL = 2
TopOpeBRepTool_BSPLINE1 = TopOpeBRepTool_OutCurveType.TopOpeBRepTool_BSPLINE1
TopOpeBRepTool_APPROX = TopOpeBRepTool_OutCurveType.TopOpeBRepTool_APPROX
TopOpeBRepTool_INTERPOL = TopOpeBRepTool_OutCurveType.TopOpeBRepTool_INTERPOL


def Handle_TopOpeBRepTool_HBoxTool_Create():
    return _TopOpeBRepTool.Handle_TopOpeBRepTool_HBoxTool_Create()

def Handle_TopOpeBRepTool_HBoxTool_DownCast(t):
    return _TopOpeBRepTool.Handle_TopOpeBRepTool_HBoxTool_DownCast(t)

def Handle_TopOpeBRepTool_HBoxTool_IsNull(t):
    return _TopOpeBRepTool.Handle_TopOpeBRepTool_HBoxTool_IsNull(t)
class TopOpeBRepTool_DataMapOfOrientedShapeC2DF(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_begin(self)

    def end(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_end(self)

    def cbegin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_cbegin(self)

    def cend(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_cend(self)

    def __init__(self, *args):
        _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_DataMapOfOrientedShapeC2DF(*args))

    def Exchange(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_Exchange(self, theOther)

    def Assign(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_Assign(self, theOther)

    def Set(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_Set(self, theOther)

    def ReSize(self, N):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_ReSize(self, N)

    def Bind(self, theKey, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_Bind(self, theKey, theItem)

    def Bound(self, theKey, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_Bound(self, theKey, theItem)

    def IsBound(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_IsBound(self, theKey)

    def UnBind(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_UnBind(self, theKey)

    def Seek(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_Seek(self, theKey)

    def Find(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_Find(self, *args)

    def ChangeSeek(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_ChangeFind(self, theKey)

    def __call__(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF___call__(self, *args)

    def Clear(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_Clear(self, *args)
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_DataMapOfOrientedShapeC2DF

    def Size(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_Size(self)

# Register TopOpeBRepTool_DataMapOfOrientedShapeC2DF in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_DataMapOfOrientedShapeC2DF_swigregister(TopOpeBRepTool_DataMapOfOrientedShapeC2DF)
class TopOpeBRepTool_DataMapOfShapeListOfC2DF(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_begin(self)

    def end(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_end(self)

    def cbegin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_cbegin(self)

    def cend(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_cend(self)

    def __init__(self, *args):
        _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_DataMapOfShapeListOfC2DF(*args))

    def Exchange(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_Exchange(self, theOther)

    def Assign(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_Assign(self, theOther)

    def Set(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_Set(self, theOther)

    def ReSize(self, N):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_ReSize(self, N)

    def Bind(self, theKey, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_Bind(self, theKey, theItem)

    def Bound(self, theKey, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_Bound(self, theKey, theItem)

    def IsBound(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_IsBound(self, theKey)

    def UnBind(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_UnBind(self, theKey)

    def Seek(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_Seek(self, theKey)

    def Find(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_Find(self, *args)

    def ChangeSeek(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_ChangeFind(self, theKey)

    def __call__(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF___call__(self, *args)

    def Clear(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_Clear(self, *args)
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_DataMapOfShapeListOfC2DF

    def Size(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_Size(self)

# Register TopOpeBRepTool_DataMapOfShapeListOfC2DF in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeListOfC2DF_swigregister(TopOpeBRepTool_DataMapOfShapeListOfC2DF)
class TopOpeBRepTool_DataMapOfShapeface(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_begin(self)

    def end(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_end(self)

    def cbegin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_cbegin(self)

    def cend(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_cend(self)

    def __init__(self, *args):
        _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_DataMapOfShapeface(*args))

    def Exchange(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_Exchange(self, theOther)

    def Assign(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_Assign(self, theOther)

    def Set(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_Set(self, theOther)

    def ReSize(self, N):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_ReSize(self, N)

    def Bind(self, theKey, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_Bind(self, theKey, theItem)

    def Bound(self, theKey, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_Bound(self, theKey, theItem)

    def IsBound(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_IsBound(self, theKey)

    def UnBind(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_UnBind(self, theKey)

    def Seek(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_Seek(self, theKey)

    def Find(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_Find(self, *args)

    def ChangeSeek(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_ChangeSeek(self, theKey)

    def ChangeFind(self, theKey):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_ChangeFind(self, theKey)

    def __call__(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface___call__(self, *args)

    def Clear(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_Clear(self, *args)
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_DataMapOfShapeface

    def Size(self):
        return _TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_Size(self)

# Register TopOpeBRepTool_DataMapOfShapeface in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_DataMapOfShapeface_swigregister(TopOpeBRepTool_DataMapOfShapeface)
class TopOpeBRepTool_IndexedDataMapOfShapeBox(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_begin(self)

    def end(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_end(self)

    def cbegin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_cbegin(self)

    def cend(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_cend(self)

    def __init__(self, *args):
        _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_IndexedDataMapOfShapeBox(*args))

    def Exchange(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_Exchange(self, theOther)

    def Assign(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_Assign(self, theOther)

    def Set(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_Set(self, theOther)

    def ReSize(self, N):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_ReSize(self, N)

    def Add(self, theKey1, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_Add(self, theKey1, theItem)

    def Contains(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_Contains(self, theKey1)

    def Substitute(self, theIndex, theKey1, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_Substitute(self, theIndex, theKey1, theItem)

    def Swap(self, theIndex1, theIndex2):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_Swap(self, theIndex1, theIndex2)

    def RemoveLast(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_RemoveLast(self)

    def RemoveFromIndex(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_RemoveFromIndex(self, theIndex)

    def RemoveKey(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_RemoveKey(self, theKey1)

    def FindKey(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_FindKey(self, theIndex)

    def FindFromIndex(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_FindFromIndex(self, theIndex)

    def ChangeFromIndex(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_ChangeFromIndex(self, theIndex)

    def __call__(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox___call__(self, *args)

    def FindIndex(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_FindIndex(self, theKey1)

    def ChangeFromKey(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_ChangeFromKey(self, theKey1)

    def Seek(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_Seek(self, theKey1)

    def ChangeSeek(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_ChangeSeek(self, theKey1)

    def FindFromKey(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_FindFromKey(self, *args)

    def Clear(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_Clear(self, *args)
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_IndexedDataMapOfShapeBox

    def Size(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_Size(self)

# Register TopOpeBRepTool_IndexedDataMapOfShapeBox in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox_swigregister(TopOpeBRepTool_IndexedDataMapOfShapeBox)
class TopOpeBRepTool_IndexedDataMapOfShapeBox2d(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_begin(self)

    def end(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_end(self)

    def cbegin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_cbegin(self)

    def cend(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_cend(self)

    def __init__(self, *args):
        _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_IndexedDataMapOfShapeBox2d(*args))

    def Exchange(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_Exchange(self, theOther)

    def Assign(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_Assign(self, theOther)

    def Set(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_Set(self, theOther)

    def ReSize(self, N):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_ReSize(self, N)

    def Add(self, theKey1, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_Add(self, theKey1, theItem)

    def Contains(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_Contains(self, theKey1)

    def Substitute(self, theIndex, theKey1, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_Substitute(self, theIndex, theKey1, theItem)

    def Swap(self, theIndex1, theIndex2):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_Swap(self, theIndex1, theIndex2)

    def RemoveLast(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_RemoveLast(self)

    def RemoveFromIndex(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_RemoveFromIndex(self, theIndex)

    def RemoveKey(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_RemoveKey(self, theKey1)

    def FindKey(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_FindKey(self, theIndex)

    def FindFromIndex(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_FindFromIndex(self, theIndex)

    def ChangeFromIndex(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_ChangeFromIndex(self, theIndex)

    def __call__(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d___call__(self, *args)

    def FindIndex(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_FindIndex(self, theKey1)

    def ChangeFromKey(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_ChangeFromKey(self, theKey1)

    def Seek(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_Seek(self, theKey1)

    def ChangeSeek(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_ChangeSeek(self, theKey1)

    def FindFromKey(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_FindFromKey(self, *args)

    def Clear(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_Clear(self, *args)
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_IndexedDataMapOfShapeBox2d

    def Size(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_Size(self)

# Register TopOpeBRepTool_IndexedDataMapOfShapeBox2d in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeBox2d_swigregister(TopOpeBRepTool_IndexedDataMapOfShapeBox2d)
class TopOpeBRepTool_IndexedDataMapOfShapeconnexity(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_begin(self)

    def end(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_end(self)

    def cbegin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_cbegin(self)

    def cend(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_cend(self)

    def __init__(self, *args):
        _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_IndexedDataMapOfShapeconnexity(*args))

    def Exchange(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_Exchange(self, theOther)

    def Assign(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_Assign(self, theOther)

    def Set(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_Set(self, theOther)

    def ReSize(self, N):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_ReSize(self, N)

    def Add(self, theKey1, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_Add(self, theKey1, theItem)

    def Contains(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_Contains(self, theKey1)

    def Substitute(self, theIndex, theKey1, theItem):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_Substitute(self, theIndex, theKey1, theItem)

    def Swap(self, theIndex1, theIndex2):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_Swap(self, theIndex1, theIndex2)

    def RemoveLast(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_RemoveLast(self)

    def RemoveFromIndex(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_RemoveFromIndex(self, theIndex)

    def RemoveKey(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_RemoveKey(self, theKey1)

    def FindKey(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_FindKey(self, theIndex)

    def FindFromIndex(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_FindFromIndex(self, theIndex)

    def ChangeFromIndex(self, theIndex):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_ChangeFromIndex(self, theIndex)

    def __call__(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity___call__(self, *args)

    def FindIndex(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_FindIndex(self, theKey1)

    def ChangeFromKey(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_ChangeFromKey(self, theKey1)

    def Seek(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_Seek(self, theKey1)

    def ChangeSeek(self, theKey1):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_ChangeSeek(self, theKey1)

    def FindFromKey(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_FindFromKey(self, *args)

    def Clear(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_Clear(self, *args)
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_IndexedDataMapOfShapeconnexity

    def Size(self):
        return _TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_Size(self)

# Register TopOpeBRepTool_IndexedDataMapOfShapeconnexity in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_IndexedDataMapOfShapeconnexity_swigregister(TopOpeBRepTool_IndexedDataMapOfShapeconnexity)
class TopOpeBRepTool_ListIteratorOfListOfC2DF(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _TopOpeBRepTool.TopOpeBRepTool_ListIteratorOfListOfC2DF_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_ListIteratorOfListOfC2DF(*args))

    def More(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListIteratorOfListOfC2DF_More(self)

    def Next(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListIteratorOfListOfC2DF_Next(self)

    def Value(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListIteratorOfListOfC2DF_Value(self)

    def ChangeValue(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListIteratorOfListOfC2DF_ChangeValue(self)
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_ListIteratorOfListOfC2DF

# Register TopOpeBRepTool_ListIteratorOfListOfC2DF in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_ListIteratorOfListOfC2DF_swigregister(TopOpeBRepTool_ListIteratorOfListOfC2DF)
class TopOpeBRepTool_ListOfC2DF(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_begin(self)

    def end(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_end(self)

    def cbegin(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_cbegin(self)

    def cend(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_cend(self)

    def __init__(self, *args):
        _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_ListOfC2DF(*args))

    def Size(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_Size(self)

    def Assign(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_Assign(self, theOther)

    def Set(self, theOther):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_Set(self, theOther)

    def Clear(self, theAllocator=0):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_Clear(self, theAllocator)

    def First(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_First(self)

    def Last(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_Last(self)

    def Append(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_Append(self, *args)

    def Prepend(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_Prepend(self, *args)

    def RemoveFirst(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_RemoveFirst(self)

    def Remove(self, theIter):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_Remove(self, theIter)

    def InsertBefore(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_InsertBefore(self, *args)

    def InsertAfter(self, *args):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_InsertAfter(self, *args)

    def Reverse(self):
        return _TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_Reverse(self)
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_ListOfC2DF

    def __len__(self):
        return self.Size()


# Register TopOpeBRepTool_ListOfC2DF in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_ListOfC2DF_swigregister(TopOpeBRepTool_ListOfC2DF)
class topopebreptool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def CorrectONUVISO(*args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        Fsp: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.topopebreptool_CorrectONUVISO(*args)

    @staticmethod
    def MakeFaces(*args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        LOF: TopTools_ListOfShape
        MshNOK: TopTools_IndexedMapOfOrientedShape
        LOFF: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        Builds up the correct list of faces <loff> from <lof>, using faulty shapes from map <mshnok>. <lof> is the list of <f>'s descendant faces. returns false if building fails.

        """
        return _TopOpeBRepTool.topopebreptool_MakeFaces(*args)

    @staticmethod
    def PurgeClosingEdges(*args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        FF: TopoDS_Face
        MWisOld: TopTools_DataMapOfShapeInteger
        MshNOK: TopTools_IndexedMapOfOrientedShape

        Return
        -------
        bool

        Description
        -----------
        Fuse edges (in a wire) of a shape where we have useless vertex. in case face <ff> is built on uv-non-connexed wires (with the two closing edges forward and reversed, in spite of one only), we find out the faulty edge, add the faulty shapes (edge,wire,face) to <mshnok>. <ff> is a face descendant of <f>. <mwisold>(wire) = 1 if wire is wire of <f> 0 wire results from <f>'s wire split. returns false if purge fails.

        Parameters
        ----------
        F: TopoDS_Face
        LOF: TopTools_ListOfShape
        MWisOld: TopTools_DataMapOfShapeInteger
        MshNOK: TopTools_IndexedMapOfOrientedShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.topopebreptool_PurgeClosingEdges(*args)

    @staticmethod
    def Regularize(*args):
        r"""

        Parameters
        ----------
        aFace: TopoDS_Face
        aListOfFaces: TopTools_ListOfShape
        ESplits: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        bool

        Description
        -----------
        Returns <false> if the face is valid (the uv representation of the face is a set of pcurves connexed by points with connexity 2). else, splits <aface> in order to return a list of valid faces.

        """
        return _TopOpeBRepTool.topopebreptool_Regularize(*args)

    @staticmethod
    def RegularizeFace(*args):
        r"""

        Parameters
        ----------
        aFace: TopoDS_Face
        OldWiresnewWires: TopTools_DataMapOfShapeListOfShape
        aListOfFaces: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        Classify wire's splits of map <oldwiresnewwires> in order to compute <alistoffaces>, the splits of <aface>.

        """
        return _TopOpeBRepTool.topopebreptool_RegularizeFace(*args)

    @staticmethod
    def RegularizeShells(*args):
        r"""

        Parameters
        ----------
        aSolid: TopoDS_Solid
        OldSheNewShe: TopTools_DataMapOfShapeListOfShape
        FSplits: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        bool

        Description
        -----------
        Returns <false> if the shell is valid (the solid is a set of faces connexed by edges with connexity 2). else, splits faces of the shell; <oldfacesnewfaces> describes (face, splits of face).

        """
        return _TopOpeBRepTool.topopebreptool_RegularizeShells(*args)

    @staticmethod
    def RegularizeWires(*args):
        r"""

        Parameters
        ----------
        aFace: TopoDS_Face
        OldWiresNewWires: TopTools_DataMapOfShapeListOfShape
        ESplits: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        bool

        Description
        -----------
        Returns <false> if the face is valid (the uv representation of the face is a set of pcurves connexed by points with connexity 2). else, splits wires of the face, these are boundaries of the new faces to build up; <oldwiresnewwires> describes (wire, splits of wire); <esplits> describes (edge, edge's splits).

        """
        return _TopOpeBRepTool.topopebreptool_RegularizeWires(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TopOpeBRepTool.topopebreptool_swiginit(self, _TopOpeBRepTool.new_topopebreptool())
    __swig_destroy__ = _TopOpeBRepTool.delete_topopebreptool

# Register topopebreptool in _TopOpeBRepTool:
_TopOpeBRepTool.topopebreptool_swigregister(topopebreptool)
class TopOpeBRepTool_AncestorsTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def MakeAncestors(*args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        TS: TopAbs_ShapeEnum
        TA: TopAbs_ShapeEnum
        M: TopTools_IndexedDataMapOfShapeListOfShape

        Return
        -------
        None

        Description
        -----------
        Same as package method topexp::mapshapelistofshapes().

        """
        return _TopOpeBRepTool.TopOpeBRepTool_AncestorsTool_MakeAncestors(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TopOpeBRepTool.TopOpeBRepTool_AncestorsTool_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_AncestorsTool())
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_AncestorsTool

# Register TopOpeBRepTool_AncestorsTool in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_AncestorsTool_swigregister(TopOpeBRepTool_AncestorsTool)
class TopOpeBRepTool_BoxSort(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        T: TopOpeBRepTool_HBoxTool

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_BoxSort_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_BoxSort(*args))

    def AddBoxes(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        TS: TopAbs_ShapeEnum
        TA: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_AddBoxes(self, *args)

    def AddBoxesMakeCOB(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        TS: TopAbs_ShapeEnum
        TA: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_AddBoxesMakeCOB(self, *args)

    def Box(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        Bnd_Box

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_Box(self, *args)

    def Clear(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_Clear(self, *args)

    def Compare(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        TColStd_ListIteratorOfListOfInteger

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_Compare(self, *args)

    def HAB(self, *args):
        r"""
        Return
        -------
        opencascade::handle<Bnd_HArray1OfBox>

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_HAB(self, *args)

    def HABShape(self, *args):
        r"""

        Parameters
        ----------
        I: int

        Return
        -------
        TopoDS_Shape

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_HABShape(self, *args)

    def HBoxTool(self, *args):
        r"""
        Return
        -------
        opencascade::handle<TopOpeBRepTool_HBoxTool>

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_HBoxTool(self, *args)

    def MakeCOB(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        TS: TopAbs_ShapeEnum
        TA: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_MakeCOB(self, *args)

    def MakeHAB(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        TS: TopAbs_ShapeEnum
        TA: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_MakeHAB(self, *args)

    @staticmethod
    def MakeHABCOB(*args):
        r"""

        Parameters
        ----------
        HAB: Bnd_HArray1OfBox
        COB: Bnd_Box

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_MakeHABCOB(*args)

    def SetHBoxTool(self, *args):
        r"""

        Parameters
        ----------
        T: TopOpeBRepTool_HBoxTool

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_SetHBoxTool(self, *args)

    def TouchedShape(self, *args):
        r"""

        Parameters
        ----------
        I: TColStd_ListIteratorOfListOfInteger

        Return
        -------
        TopoDS_Shape

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_BoxSort_TouchedShape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_BoxSort

# Register TopOpeBRepTool_BoxSort in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_BoxSort_swigregister(TopOpeBRepTool_BoxSort)
class TopOpeBRepTool_C2DF(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        PC: Geom2d_Curve
        f2d: float
        l2d: float
        tol: float
        F: TopoDS_Face

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_C2DF_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_C2DF(*args))

    def Face(self, *args):
        r"""
        Return
        -------
        TopoDS_Face

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_C2DF_Face(self, *args)

    def IsFace(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_C2DF_IsFace(self, *args)

    def IsPC(self, *args):
        r"""

        Parameters
        ----------
        PC: Geom2d_Curve

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_C2DF_IsPC(self, *args)

    def PC(self, *args):
        r"""

        Parameters
        ----------

        Return
        -------
        f2d: float
        l2d: float
        tol: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_C2DF_PC(self, *args)

    def SetFace(self, *args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_C2DF_SetFace(self, *args)

    def SetPC(self, *args):
        r"""

        Parameters
        ----------
        PC: Geom2d_Curve
        f2d: float
        l2d: float
        tol: float

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_C2DF_SetPC(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_C2DF

# Register TopOpeBRepTool_C2DF in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_C2DF_swigregister(TopOpeBRepTool_C2DF)
class TopOpeBRepTool_CLASSI(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_CLASSI_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_CLASSI(*args))

    def Add2d(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CLASSI_Add2d(self, *args)

    def ClassiBnd2d(self, *args):
        r"""

        Parameters
        ----------
        S1: TopoDS_Shape
        S2: TopoDS_Shape
        tol: float
        checklarge: bool

        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CLASSI_ClassiBnd2d(self, *args)

    def Classilist(self, *args):
        r"""

        Parameters
        ----------
        lS: TopTools_ListOfShape
        mapgreasma: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CLASSI_Classilist(self, *args)

    def Classip2d(self, *args):
        r"""

        Parameters
        ----------
        S1: TopoDS_Shape
        S2: TopoDS_Shape
        stabnd2d12: int

        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CLASSI_Classip2d(self, *args)

    def GetBox2d(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        Box2d: Bnd_Box2d

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CLASSI_GetBox2d(self, *args)

    def Getface(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        fa: TopOpeBRepTool_face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CLASSI_Getface(self, *args)

    def HasInit2d(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CLASSI_HasInit2d(self, *args)

    def Init2d(self, *args):
        r"""

        Parameters
        ----------
        Fref: TopoDS_Face

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CLASSI_Init2d(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_CLASSI

# Register TopOpeBRepTool_CLASSI in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_CLASSI_swigregister(TopOpeBRepTool_CLASSI)
class TopOpeBRepTool_CORRISO(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        FRef: TopoDS_Face

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_CORRISO_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_CORRISO(*args))

    def AddNewConnexity(self, *args):
        r"""

        Parameters
        ----------
        V: TopoDS_Vertex
        E: TopoDS_Edge

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_AddNewConnexity(self, *args)

    def Connexity(self, *args):
        r"""

        Parameters
        ----------
        V: TopoDS_Vertex
        Eds: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_Connexity(self, *args)

    def EdgeOUTofBoundsUV(self, *args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge
        onU: bool
        tolx: float

        Return
        -------
        parspE: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_EdgeOUTofBoundsUV(self, *args)

    def EdgeWithFaultyUV(self, *args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge

        Return
        -------
        Ivfaulty: int

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        EdsToCheck: TopTools_ListOfShape
        nfybounds: int
        fyE: TopoDS_Shape

        Return
        -------
        Ifaulty: int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_EdgeWithFaultyUV(self, *args)

    def EdgesOUTofBoundsUV(self, *args):
        r"""

        Parameters
        ----------
        EdsToCheck: TopTools_ListOfShape
        onU: bool
        tolx: float
        FyEds: TopTools_DataMapOfOrientedShapeInteger

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_EdgesOUTofBoundsUV(self, *args)

    def EdgesWithFaultyUV(self, *args):
        r"""

        Parameters
        ----------
        EdsToCheck: TopTools_ListOfShape
        nfybounds: int
        FyEds: TopTools_DataMapOfOrientedShapeInteger
        stopatfirst: bool (optional, default to Standard_False)

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_EdgesWithFaultyUV(self, *args)

    def Eds(self, *args):
        r"""
        Return
        -------
        TopTools_ListOfShape

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_Eds(self, *args)

    def Fref(self, *args):
        r"""
        Return
        -------
        TopoDS_Face

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_Fref(self, *args)

    def GASref(self, *args):
        r"""
        Return
        -------
        GeomAdaptor_Surface

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_GASref(self, *args)

    def GetnewS(self, *args):
        r"""

        Parameters
        ----------
        newS: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_GetnewS(self, *args)

    def Init(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_Init(self, *args)

    def PurgeFyClosingE(self, *args):
        r"""

        Parameters
        ----------
        ClEds: TopTools_ListOfShape
        fyClEds: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_PurgeFyClosingE(self, *args)

    def Refclosed(self, *args):
        r"""

        Parameters
        ----------
        x: int

        Return
        -------
        xperiod: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_Refclosed(self, *args)

    def RemoveOldConnexity(self, *args):
        r"""

        Parameters
        ----------
        V: TopoDS_Vertex
        E: TopoDS_Edge

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_RemoveOldConnexity(self, *args)

    def S(self, *args):
        r"""
        Return
        -------
        TopoDS_Shape

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_S(self, *args)

    def SetConnexity(self, *args):
        r"""

        Parameters
        ----------
        V: TopoDS_Vertex
        Eds: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_SetConnexity(self, *args)

    def SetUVRep(self, *args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge
        C2DF: TopOpeBRepTool_C2DF

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_SetUVRep(self, *args)

    def Tol(self, *args):
        r"""

        Parameters
        ----------
        I: int
        tol3d: float

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_Tol(self, *args)

    def TrslUV(self, *args):
        r"""

        Parameters
        ----------
        onU: bool
        FyEds: TopTools_DataMapOfOrientedShapeInteger

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_TrslUV(self, *args)

    def UVClosed(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_UVClosed(self, *args)

    def UVRep(self, *args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge
        C2DF: TopOpeBRepTool_C2DF

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CORRISO_UVRep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_CORRISO

# Register TopOpeBRepTool_CORRISO in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_CORRISO_swigregister(TopOpeBRepTool_CORRISO)
class TopOpeBRepTool_CurveTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        OCT: TopOpeBRepTool_OutCurveType

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        GT: TopOpeBRepTool_GeomTool

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_CurveTool_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_CurveTool(*args))

    def ChangeGeomTool(self, *args):
        r"""
        Return
        -------
        TopOpeBRepTool_GeomTool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CurveTool_ChangeGeomTool(self, *args)

    def GetGeomTool(self, *args):
        r"""
        Return
        -------
        TopOpeBRepTool_GeomTool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CurveTool_GetGeomTool(self, *args)

    @staticmethod
    def IsProjectable(*args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        C: Geom_Curve

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CurveTool_IsProjectable(*args)

    @staticmethod
    def MakeBSpline1fromPnt(*args):
        r"""

        Parameters
        ----------
        P: TColgp_Array1OfPnt

        Return
        -------
        opencascade::handle<Geom_Curve>

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CurveTool_MakeBSpline1fromPnt(*args)

    @staticmethod
    def MakeBSpline1fromPnt2d(*args):
        r"""

        Parameters
        ----------
        P: TColgp_Array1OfPnt2d

        Return
        -------
        opencascade::handle<Geom2d_Curve>

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CurveTool_MakeBSpline1fromPnt2d(*args)

    def MakeCurves(self, *args):
        r"""

        Parameters
        ----------
        min: float
        max: float
        C3D: Geom_Curve
        PC1: Geom2d_Curve
        PC2: Geom2d_Curve
        S1: TopoDS_Shape
        S2: TopoDS_Shape
        C3DN: Geom_Curve
        PC1N: Geom2d_Curve
        PC2N: Geom2d_Curve

        Return
        -------
        Tol3d: float
        Tol2d: float

        Description
        -----------
        Approximates curves. returns false in the case of failure.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CurveTool_MakeCurves(self, *args)

    @staticmethod
    def MakePCurveOnFace(*args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        C: Geom_Curve
        first: float (optional, default to 0.0)
        last: float (optional, default to 0.0)

        Return
        -------
        TolReached2d: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CurveTool_MakePCurveOnFace(*args)

    def SetGeomTool(self, *args):
        r"""

        Parameters
        ----------
        GT: TopOpeBRepTool_GeomTool

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_CurveTool_SetGeomTool(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_CurveTool

# Register TopOpeBRepTool_CurveTool in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_CurveTool_swigregister(TopOpeBRepTool_CurveTool)
class TopOpeBRepTool_FuseEdges(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""

        Parameters
        ----------
        theShape: TopoDS_Shape
        PerformNow: bool (optional, default to Standard_False)

        Return
        -------
        None

        Description
        -----------
        Initialise members and build construction of map of ancestors.

        """
        _TopOpeBRepTool.TopOpeBRepTool_FuseEdges_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_FuseEdges(*args))

    def AvoidEdges(self, *args):
        r"""

        Parameters
        ----------
        theMapEdg: TopTools_IndexedMapOfShape

        Return
        -------
        None

        Description
        -----------
        Set edges to avoid being fused.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_FuseEdges_AvoidEdges(self, *args)

    def Edges(self, *args):
        r"""

        Parameters
        ----------
        theMapLstEdg: TopTools_DataMapOfIntegerListOfShape

        Return
        -------
        None

        Description
        -----------
        Returns all the list of edges to be fused each list of the map represent a set of connex edges that can be fused.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_FuseEdges_Edges(self, *args)

    def Faces(self, *args):
        r"""

        Parameters
        ----------
        theMapFac: TopTools_DataMapOfShapeShape

        Return
        -------
        None

        Description
        -----------
        Returns the map of modified faces.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_FuseEdges_Faces(self, *args)

    def NbVertices(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns the number of vertices candidate to be removed.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_FuseEdges_NbVertices(self, *args)

    def Perform(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Using map of list of connex edges, fuse each list to one edge and then update myshape.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_FuseEdges_Perform(self, *args)

    def ResultEdges(self, *args):
        r"""

        Parameters
        ----------
        theMapEdg: TopTools_DataMapOfIntegerShape

        Return
        -------
        None

        Description
        -----------
        Returns all the fused edges. each integer entry in the map corresponds to the integer in the datamapofintegerlistofshape we get in method edges. that is to say, to the list of edges in themaplstedg(i) corresponds the resulting edge themapedge(i).

        """
        return _TopOpeBRepTool.TopOpeBRepTool_FuseEdges_ResultEdges(self, *args)

    def Shape(self, *args):
        r"""
        Return
        -------
        TopoDS_Shape

        Description
        -----------
        Returns myshape modified with the list of internal edges removed from it.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_FuseEdges_Shape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_FuseEdges

# Register TopOpeBRepTool_FuseEdges in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_FuseEdges_swigregister(TopOpeBRepTool_FuseEdges)
class TopOpeBRepTool_GeomTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""

        Parameters
        ----------
        TypeC3D: TopOpeBRepTool_OutCurveType (optional, default to TopOpeBRepTool_BSPLINE1)
        CompC3D: bool (optional, default to Standard_True)
        CompPC1: bool (optional, default to Standard_True)
        CompPC2: bool (optional, default to Standard_True)

        Return
        -------
        None

        Description
        -----------
        Boolean flags <compc3d>, <comppc1>, <comppc2> indicate whether the corresponding result curves <c3d>, <pc1>, <pc2> of makecurves method must or not be computed from an intersection line <l>. when the line <l> is a walking one, <typec3d> is the kind of the 3d curve <c3d> to compute: - bspline1 to compute a bspline of degree 1 on the walking points of <l>, - approx to build an approximation curve on the walking points of <l>.

        """
        _TopOpeBRepTool.TopOpeBRepTool_GeomTool_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_GeomTool(*args))

    def CompC3D(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_CompC3D(self, *args)

    def CompPC1(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_CompPC1(self, *args)

    def CompPC2(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_CompPC2(self, *args)

    def Define(self, *args):
        r"""

        Parameters
        ----------
        TypeC3D: TopOpeBRepTool_OutCurveType
        CompC3D: bool
        CompPC1: bool
        CompPC2: bool

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        TypeC3D: TopOpeBRepTool_OutCurveType

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        GT: TopOpeBRepTool_GeomTool

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_Define(self, *args)

    def DefineCurves(self, *args):
        r"""

        Parameters
        ----------
        CompC3D: bool

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_DefineCurves(self, *args)

    def DefinePCurves1(self, *args):
        r"""

        Parameters
        ----------
        CompPC1: bool

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_DefinePCurves1(self, *args)

    def DefinePCurves2(self, *args):
        r"""

        Parameters
        ----------
        CompPC2: bool

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_DefinePCurves2(self, *args)

    def GetTolerances(self, *args):
        r"""

        Parameters
        ----------

        Return
        -------
        tol3d: float
        tol2d: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_GetTolerances(self, *args)

    def NbPntMax(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_NbPntMax(self, *args)

    def SetNbPntMax(self, *args):
        r"""

        Parameters
        ----------
        NbPntMax: int

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_SetNbPntMax(self, *args)

    def SetTolerances(self, *args):
        r"""

        Parameters
        ----------
        tol3d: float
        tol2d: float

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_SetTolerances(self, *args)

    def TypeC3D(self, *args):
        r"""
        Return
        -------
        TopOpeBRepTool_OutCurveType

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_GeomTool_TypeC3D(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_GeomTool

# Register TopOpeBRepTool_GeomTool in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_GeomTool_swigregister(TopOpeBRepTool_GeomTool)
class TopOpeBRepTool_HBoxTool(OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_HBoxTool(*args))

    def AddBox(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_AddBox(self, *args)

    def AddBoxes(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        TS: TopAbs_ShapeEnum
        TA: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_AddBoxes(self, *args)

    def Box(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        Bnd_Box

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        I: int

        Return
        -------
        Bnd_Box

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_Box(self, *args)

    def ChangeIMS(self, *args):
        r"""
        Return
        -------
        TopOpeBRepTool_IndexedDataMapOfShapeBox

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_ChangeIMS(self, *args)

    def Clear(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_Clear(self, *args)

    @staticmethod
    def ComputeBox(*args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        B: Bnd_Box

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_ComputeBox(*args)

    @staticmethod
    def ComputeBoxOnVertices(*args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        B: Bnd_Box

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_ComputeBoxOnVertices(*args)

    @staticmethod
    def DumpB(*args):
        r"""

        Parameters
        ----------
        B: Bnd_Box

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_DumpB(*args)

    def Extent(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_Extent(self, *args)

    def HasBox(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_HasBox(self, *args)

    def IMS(self, *args):
        r"""
        Return
        -------
        TopOpeBRepTool_IndexedDataMapOfShapeBox

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_IMS(self, *args)

    def Index(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_Index(self, *args)

    def Shape(self, *args):
        r"""

        Parameters
        ----------
        I: int

        Return
        -------
        TopoDS_Shape

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_HBoxTool_Shape(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_TopOpeBRepTool_HBoxTool_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_HBoxTool

# Register TopOpeBRepTool_HBoxTool in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_HBoxTool_swigregister(TopOpeBRepTool_HBoxTool)
class TopOpeBRepTool_PurgeInternalEdges(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""

        Parameters
        ----------
        theShape: TopoDS_Shape
        PerformNow: bool (optional, default to Standard_True)

        Return
        -------
        None

        Description
        -----------
        Initialize members and begin exploration of shape depending of the value of performnow.

        """
        _TopOpeBRepTool.TopOpeBRepTool_PurgeInternalEdges_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_PurgeInternalEdges(*args))

    def Faces(self, *args):
        r"""

        Parameters
        ----------
        theMapFacLstEdg: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        None

        Description
        -----------
        Returns the list internal edges associated with the faces of the myshape. if performnow was false when created, then call the private perform method that do the main job.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_PurgeInternalEdges_Faces(self, *args)

    def IsDone(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        Returns false if the list of internal edges has not been extracted.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_PurgeInternalEdges_IsDone(self, *args)

    def NbEdges(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Returns the number of edges candidate to be removed.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_PurgeInternalEdges_NbEdges(self, *args)

    def Perform(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Using the list of internal edge from each face, rebuild myshape by removing thoses edges.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_PurgeInternalEdges_Perform(self, *args)

    def Shape(self, *args):
        r"""
        Return
        -------
        TopoDS_Shape

        Description
        -----------
        Returns myshape modified with the list of internal edges removed from it.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_PurgeInternalEdges_Shape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_PurgeInternalEdges

# Register TopOpeBRepTool_PurgeInternalEdges in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_PurgeInternalEdges_swigregister(TopOpeBRepTool_PurgeInternalEdges)
class TopOpeBRepTool_REGUS(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_REGUS_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_REGUS(*args))

    def GetFsplits(self, *args):
        r"""

        Parameters
        ----------
        Fsplits: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_GetFsplits(self, *args)

    def GetOshNsh(self, *args):
        r"""

        Parameters
        ----------
        OshNsh: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_GetOshNsh(self, *args)

    def Init(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_Init(self, *args)

    def InitBlock(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_InitBlock(self, *args)

    def MapS(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_MapS(self, *args)

    def NearestF(self, *args):
        r"""

        Parameters
        ----------
        e: TopoDS_Edge
        lof: TopTools_ListOfShape
        ffound: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_NearestF(self, *args)

    def NextinBlock(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_NextinBlock(self, *args)

    def REGU(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_REGU(self, *args)

    def S(self, *args):
        r"""
        Return
        -------
        TopoDS_Shape

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_S(self, *args)

    def SetFsplits(self, *args):
        r"""

        Parameters
        ----------
        Fsplits: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_SetFsplits(self, *args)

    def SetOshNsh(self, *args):
        r"""

        Parameters
        ----------
        OshNsh: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_SetOshNsh(self, *args)

    @staticmethod
    def SplitF(*args):
        r"""

        Parameters
        ----------
        Fanc: TopoDS_Face
        FSplits: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_SplitF(*args)

    def SplitFaces(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_SplitFaces(self, *args)

    @staticmethod
    def WireToFace(*args):
        r"""

        Parameters
        ----------
        Fanc: TopoDS_Face
        nWs: TopTools_ListOfShape
        nFs: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUS_WireToFace(*args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_REGUS

# Register TopOpeBRepTool_REGUS in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_REGUS_swigregister(TopOpeBRepTool_REGUS)
class TopOpeBRepTool_REGUW(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""

        Parameters
        ----------
        FRef: TopoDS_Face

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_REGUW_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_REGUW(*args))

    def AddNewConnexity(self, *args):
        r"""

        Parameters
        ----------
        v: TopoDS_Vertex
        OriKey: int
        e: TopoDS_Edge

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_AddNewConnexity(self, *args)

    def Connexity(self, *args):
        r"""

        Parameters
        ----------
        v: TopoDS_Vertex
        co: TopOpeBRepTool_connexity

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_Connexity(self, *args)

    def Fref(self, *args):
        r"""
        Return
        -------
        TopoDS_Face

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_Fref(self, *args)

    def GetEsplits(self, *args):
        r"""

        Parameters
        ----------
        Esplits: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_GetEsplits(self, *args)

    def GetOwNw(self, *args):
        r"""

        Parameters
        ----------
        OwNw: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_GetOwNw(self, *args)

    def GetSplits(self, *args):
        r"""

        Parameters
        ----------
        Splits: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_GetSplits(self, *args)

    def HasInit(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_HasInit(self, *args)

    def Init(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_Init(self, *args)

    def InitBlock(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_InitBlock(self, *args)

    def MapS(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_MapS(self, *args)

    def NearestE(self, *args):
        r"""

        Parameters
        ----------
        loe: TopTools_ListOfShape
        efound: TopoDS_Edge

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_NearestE(self, *args)

    def NextinBlock(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_NextinBlock(self, *args)

    def REGU(self, *args):
        r"""

        Parameters
        ----------
        istep: int
        Scur: TopoDS_Shape
        Splits: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_REGU(self, *args)

    def RemoveOldConnexity(self, *args):
        r"""

        Parameters
        ----------
        v: TopoDS_Vertex
        OriKey: int
        e: TopoDS_Edge

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_RemoveOldConnexity(self, *args)

    def S(self, *args):
        r"""
        Return
        -------
        TopoDS_Shape

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_S(self, *args)

    def SetEsplits(self, *args):
        r"""

        Parameters
        ----------
        Esplits: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_SetEsplits(self, *args)

    def SetOwNw(self, *args):
        r"""

        Parameters
        ----------
        OwNw: TopTools_DataMapOfShapeListOfShape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_SetOwNw(self, *args)

    def SplitEds(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_SplitEds(self, *args)

    def UpdateMultiple(self, *args):
        r"""

        Parameters
        ----------
        v: TopoDS_Vertex

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_REGUW_UpdateMultiple(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_REGUW

# Register TopOpeBRepTool_REGUW in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_REGUW_swigregister(TopOpeBRepTool_REGUW)
class TopOpeBRepTool_ShapeClassifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        SRef: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        Sref is the reference shape. stateshapeshape(s) calls will classify s with sref.

        """
        _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_ShapeClassifier(*args))

    def ChangeSolidClassifier(self, *args):
        r"""
        Return
        -------
        TopOpeBRepTool_SolidClassifier

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_ChangeSolidClassifier(self, *args)

    def ClearAll(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Reset all internal data (solidclassifier included).

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_ClearAll(self, *args)

    def ClearCurrent(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Reset all internal data (except solidclassified).

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_ClearCurrent(self, *args)

    def P2D(self, *args):
        r"""
        Return
        -------
        gp_Pnt2d

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_P2D(self, *args)

    def P3D(self, *args):
        r"""
        Return
        -------
        gp_Pnt

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_P3D(self, *args)

    def SameDomain(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        samedomain: int

        Return
        -------
        None

        Description
        -----------
        Set mode for next stateshapeshape call samedomain = true --> s,sref are same domain --> point on restriction (on s) is used to classify s. samedomain = false --> s,sref are not domain --> point not on restriction of s (in s) is used to classify s. samedomain value is used only in next stateshapeshape call.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_SameDomain(self, *args)

    def SetReference(self, *args):
        r"""

        Parameters
        ----------
        SRef: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        Set sref as reference shape the next stateshapereference(s,avoids) calls will classify s with sref.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_SetReference(self, *args)

    def State(self, *args):
        r"""
        Return
        -------
        TopAbs_State

        Description
        -----------
        Return field mystate.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_State(self, *args)

    def StateP2DReference(self, *args):
        r"""

        Parameters
        ----------
        P2D: gp_Pnt2d

        Return
        -------
        None

        Description
        -----------
        Classify point p2d with myref.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_StateP2DReference(self, *args)

    def StateP3DReference(self, *args):
        r"""

        Parameters
        ----------
        P3D: gp_Pnt

        Return
        -------
        None

        Description
        -----------
        Classify point p3d with myref.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_StateP3DReference(self, *args)

    def StateShapeReference(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        AvoidS: TopoDS_Shape

        Return
        -------
        TopAbs_State

        Description
        -----------
        Classify shape s compared with reference shape. avoids is not used in classification; avoids may be isnull(). (useful to avoid on or unknown state in special cases).

        Parameters
        ----------
        S: TopoDS_Shape
        LAvoidS: TopTools_ListOfShape

        Return
        -------
        TopAbs_State

        Description
        -----------
        Classify shape s compared with reference shape. lavoids is list of s subshapes to avoid in classification (useful to avoid on or unknown state in special cases).

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_StateShapeReference(self, *args)

    def StateShapeShape(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        SRef: TopoDS_Shape
        samedomain: int (optional, default to 0)

        Return
        -------
        TopAbs_State

        Description
        -----------
        Classify shape s compared with shape sref. samedomain = 0: s1,s2 are not same domain samedomain = 1: s1,s2 are same domain.

        Parameters
        ----------
        S: TopoDS_Shape
        AvoidS: TopoDS_Shape
        SRef: TopoDS_Shape

        Return
        -------
        TopAbs_State

        Description
        -----------
        Classify shape s compared with shape sref. avoids is not used in classification; avoids may be isnull(). (useful to avoid on or unknown state in special cases).

        Parameters
        ----------
        S: TopoDS_Shape
        LAvoidS: TopTools_ListOfShape
        SRef: TopoDS_Shape

        Return
        -------
        TopAbs_State

        Description
        -----------
        Classify shape s compared with shape sref. lavoids is list of s subshapes to avoid in classification avoids is not used in classification; avoids may be isnull(). (useful to avoid on or unknown state in special cases).

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_StateShapeShape(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_ShapeClassifier

# Register TopOpeBRepTool_ShapeClassifier in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_ShapeClassifier_swigregister(TopOpeBRepTool_ShapeClassifier)
class TopOpeBRepTool_ShapeExplorer(OCC.Core.TopExp.TopExp_Explorer):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Creates an empty explorer, becomes useful after init.

        Parameters
        ----------
        S: TopoDS_Shape
        ToFind: TopAbs_ShapeEnum
        ToAvoid: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        None

        Description
        -----------
        Creates an explorer on the shape <s>. //! <tofind> is the type of shapes to search. topabs_vertex, topabs_edge, ... //! <toavoid> is the type of shape to skip in the exploration. if <toavoid> is equal or less complex than <tofind> or if <toavoid> is shape it has no effect on the exploration.

        """
        _TopOpeBRepTool.TopOpeBRepTool_ShapeExplorer_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_ShapeExplorer(*args))

    def DumpCurrentToString(self):
        r"""DumpCurrentToString(TopOpeBRepTool_ShapeExplorer self) -> std::string"""
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeExplorer_DumpCurrentToString(self)

    def Index(self, *args):
        r"""
        Return
        -------
        int

        Description
        -----------
        Index of current sub-shape.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeExplorer_Index(self, *args)

    def Init(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape
        ToFind: TopAbs_ShapeEnum
        ToAvoid: TopAbs_ShapeEnum (optional, default to TopAbs_SHAPE)

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeExplorer_Init(self, *args)

    def Next(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        Moves to the next shape in the exploration.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeExplorer_Next(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_ShapeExplorer

# Register TopOpeBRepTool_ShapeExplorer in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_ShapeExplorer_swigregister(TopOpeBRepTool_ShapeExplorer)
class TopOpeBRepTool_ShapeTool(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def AdjustOnPeriodic(*args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        u: float
        v: float

        Description
        -----------
        Adjust u,v values in uvbounds of the domain of the geometric shape <s>, according to uperiodicity and vperiodicity of the domain. <s> is assumed to be a face. u and/or v is/are not modified when the domain is not periodic in u and/or v .

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_AdjustOnPeriodic(*args)

    @staticmethod
    def BASISCURVE(*args):
        r"""

        Parameters
        ----------
        C: Geom_Curve

        Return
        -------
        opencascade::handle<Geom_Curve>

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge

        Return
        -------
        opencascade::handle<Geom_Curve>

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_BASISCURVE(*args)

    @staticmethod
    def BASISSURFACE(*args):
        r"""

        Parameters
        ----------
        S: Geom_Surface

        Return
        -------
        opencascade::handle<Geom_Surface>

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Return
        -------
        opencascade::handle<Geom_Surface>

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_BASISSURFACE(*args)

    @staticmethod
    def Closed(*args):
        r"""

        Parameters
        ----------
        S1: TopoDS_Shape
        S2: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        Indicates whether shape s1 is a closing shape on s2 or not.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_Closed(*args)

    @staticmethod
    def CurvesSameOriented(*args):
        r"""

        Parameters
        ----------
        C1: BRepAdaptor_Curve
        C2: BRepAdaptor_Curve

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_CurvesSameOriented(*args)

    @staticmethod
    def EdgeData(*args):
        r"""

        Parameters
        ----------
        BRAC: BRepAdaptor_Curve
        P: float
        T: gp_Dir
        N: gp_Dir

        Return
        -------
        C: float

        Description
        -----------
        Compute tangent t, normal n, curvature c at point of parameter p on curve brac. returns the tolerance indicating if t,n are null.

        Parameters
        ----------
        E: TopoDS_Shape
        P: float
        T: gp_Dir
        N: gp_Dir

        Return
        -------
        C: float

        Description
        -----------
        Same as previous on edge e.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_EdgeData(*args)

    @staticmethod
    def EdgesSameOriented(*args):
        r"""

        Parameters
        ----------
        E1: TopoDS_Shape
        E2: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_EdgesSameOriented(*args)

    @staticmethod
    def FacesSameOriented(*args):
        r"""

        Parameters
        ----------
        F1: TopoDS_Shape
        F2: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_FacesSameOriented(*args)

    @staticmethod
    def PeriodizeParameter(*args):
        r"""

        Parameters
        ----------
        par: float
        EE: TopoDS_Shape
        FF: TopoDS_Shape

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_PeriodizeParameter(*args)

    @staticmethod
    def Pnt(*args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        gp_Pnt

        Description
        -----------
        Returns 3d point of vertex <s>.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_Pnt(*args)

    @staticmethod
    def Resolution3d(*args):
        r"""

        Parameters
        ----------
        SU: Geom_Surface
        Tol2d: float

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face
        Tol2d: float

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_Resolution3d(*args)

    @staticmethod
    def Resolution3dU(*args):
        r"""

        Parameters
        ----------
        SU: Geom_Surface
        Tol2d: float

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_Resolution3dU(*args)

    @staticmethod
    def Resolution3dV(*args):
        r"""

        Parameters
        ----------
        SU: Geom_Surface
        Tol2d: float

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_Resolution3dV(*args)

    @staticmethod
    def ShapesSameOriented(*args):
        r"""

        Parameters
        ----------
        S1: TopoDS_Shape
        S2: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_ShapesSameOriented(*args)

    @staticmethod
    def SurfacesSameOriented(*args):
        r"""

        Parameters
        ----------
        S1: BRepAdaptor_Surface
        S2: BRepAdaptor_Surface

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_SurfacesSameOriented(*args)

    @staticmethod
    def Tolerance(*args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shape

        Return
        -------
        float

        Description
        -----------
        Returns the tolerance of the shape <s>. if the shape <s> is null, returns 0.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_Tolerance(*args)

    @staticmethod
    def UVBOUNDS(*args):
        r"""

        Parameters
        ----------
        S: Geom_Surface

        Return
        -------
        UPeri: bool
        VPeri: bool
        Umin: float
        Umax: float
        Vmin: float
        Vmax: float

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Return
        -------
        UPeri: bool
        VPeri: bool
        Umin: float
        Umax: float
        Vmin: float
        Vmax: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_UVBOUNDS(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TopOpeBRepTool.TopOpeBRepTool_ShapeTool_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_ShapeTool())
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_ShapeTool

# Register TopOpeBRepTool_ShapeTool in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_ShapeTool_swigregister(TopOpeBRepTool_ShapeTool)
class TopOpeBRepTool_SolidClassifier(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_SolidClassifier_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_SolidClassifier(*args))

    def Classify(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Solid
        P: gp_Pnt
        Tol: float

        Return
        -------
        TopAbs_State

        Description
        -----------
        Compute the position of point <p> regarding with the geometric domain of the solid <s>.

        Parameters
        ----------
        S: TopoDS_Shell
        P: gp_Pnt
        Tol: float

        Return
        -------
        TopAbs_State

        Description
        -----------
        Compute the position of point <p> regarding with the geometric domain of the shell <s>.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_SolidClassifier_Classify(self, *args)

    def Clear(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_SolidClassifier_Clear(self, *args)

    def LoadShell(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Shell

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_SolidClassifier_LoadShell(self, *args)

    def LoadSolid(self, *args):
        r"""

        Parameters
        ----------
        S: TopoDS_Solid

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_SolidClassifier_LoadSolid(self, *args)

    def State(self, *args):
        r"""
        Return
        -------
        TopAbs_State

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_SolidClassifier_State(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_SolidClassifier

# Register TopOpeBRepTool_SolidClassifier in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_SolidClassifier_swigregister(TopOpeBRepTool_SolidClassifier)
class TopOpeBRepTool_TOOL(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    @staticmethod
    def ClosedE(*args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge
        vclo: TopoDS_Vertex

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_ClosedE(*args)

    @staticmethod
    def ClosedS(*args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_ClosedS(*args)

    @staticmethod
    def CurvE(*args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge
        par: float
        tg0: gp_Dir

        Return
        -------
        Curv: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_CurvE(*args)

    @staticmethod
    def CurvF(*args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        uv: gp_Pnt2d
        tg0: gp_Dir

        Return
        -------
        Curv: float
        direct: bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_CurvF(*args)

    @staticmethod
    def EdgeONFace(*args):
        r"""

        Parameters
        ----------
        par: float
        ed: TopoDS_Edge
        uv: gp_Pnt2d
        fa: TopoDS_Face

        Return
        -------
        isonfa: bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_EdgeONFace(*args)

    @staticmethod
    def Getduv(*args):
        r"""

        Parameters
        ----------
        f: TopoDS_Face
        uv: gp_Pnt2d
        dir: gp_Vec
        factor: float
        duv: gp_Dir2d

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_Getduv(*args)

    @staticmethod
    def Getstp3dF(*args):
        r"""

        Parameters
        ----------
        p: gp_Pnt
        f: TopoDS_Face
        uv: gp_Pnt2d
        st: TopAbs_State

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_Getstp3dF(*args)

    @staticmethod
    def IsClosingE(*args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge
        W: TopoDS_Shape
        F: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_IsClosingE(*args)

    @staticmethod
    def IsQuad(*args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        F: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_IsQuad(*args)

    @staticmethod
    def IsonCLO(*args):
        r"""

        Parameters
        ----------
        PC: Geom2d_Curve
        onU: bool
        xfirst: float
        xperiod: float
        xtol: float

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        C2DF: TopOpeBRepTool_C2DF
        onU: bool
        xfirst: float
        xperiod: float
        xtol: float

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_IsonCLO(*args)

    @staticmethod
    def Matter(*args):
        r"""

        Parameters
        ----------
        d1: gp_Vec
        d2: gp_Vec
        ref: gp_Vec

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        d1: gp_Vec2d
        d2: gp_Vec2d

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        xx1: gp_Dir
        nt1: gp_Dir
        xx2: gp_Dir
        nt2: gp_Dir
        tola: float

        Return
        -------
        Ang: float

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        f1: TopoDS_Face
        f2: TopoDS_Face
        e: TopoDS_Edge
        pare: float
        tola: float

        Return
        -------
        Ang: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_Matter(*args)

    @staticmethod
    def MatterKPtg(*args):
        r"""

        Parameters
        ----------
        f1: TopoDS_Face
        f2: TopoDS_Face
        e: TopoDS_Edge

        Return
        -------
        Ang: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_MatterKPtg(*args)

    @staticmethod
    def MkShell(*args):
        r"""

        Parameters
        ----------
        lF: TopTools_ListOfShape
        She: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_MkShell(*args)

    @staticmethod
    def NgApp(*args):
        r"""

        Parameters
        ----------
        par: float
        E: TopoDS_Edge
        F: TopoDS_Face
        tola: float
        ngApp: gp_Dir

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_NgApp(*args)

    @staticmethod
    def NggeomF(*args):
        r"""

        Parameters
        ----------
        uv: gp_Pnt2d
        F: TopoDS_Face
        ng: gp_Vec

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_NggeomF(*args)

    @staticmethod
    def Nt(*args):
        r"""

        Parameters
        ----------
        uv: gp_Pnt2d
        f: TopoDS_Face
        normt: gp_Dir

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_Nt(*args)

    @staticmethod
    def OnBoundary(*args):
        r"""

        Parameters
        ----------
        par: float
        E: TopoDS_Edge

        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_OnBoundary(*args)

    @staticmethod
    def OriinSor(*args):
        r"""

        Parameters
        ----------
        sub: TopoDS_Shape
        S: TopoDS_Shape
        checkclo: bool (optional, default to Standard_False)

        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_OriinSor(*args)

    @staticmethod
    def OriinSorclosed(*args):
        r"""

        Parameters
        ----------
        sub: TopoDS_Shape
        S: TopoDS_Shape

        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_OriinSorclosed(*args)

    @staticmethod
    def ParE(*args):
        r"""

        Parameters
        ----------
        Iv: int
        E: TopoDS_Edge

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_ParE(*args)

    @staticmethod
    def ParE2d(*args):
        r"""

        Parameters
        ----------
        p2d: gp_Pnt2d
        e: TopoDS_Edge
        f: TopoDS_Face

        Return
        -------
        par: float
        dist: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_ParE2d(*args)

    @staticmethod
    def ParISO(*args):
        r"""

        Parameters
        ----------
        p2d: gp_Pnt2d
        e: TopoDS_Edge
        f: TopoDS_Face

        Return
        -------
        pare: float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_ParISO(*args)

    @staticmethod
    def Remove(*args):
        r"""

        Parameters
        ----------
        loS: TopTools_ListOfShape
        toremove: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_Remove(*args)

    @staticmethod
    def SplitE(*args):
        r"""

        Parameters
        ----------
        Eanc: TopoDS_Edge
        Splits: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_SplitE(*args)

    @staticmethod
    def Tg2d(*args):
        r"""

        Parameters
        ----------
        iv: int
        E: TopoDS_Edge
        C2DF: TopOpeBRepTool_C2DF

        Return
        -------
        gp_Vec2d

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_Tg2d(*args)

    @staticmethod
    def Tg2dApp(*args):
        r"""

        Parameters
        ----------
        iv: int
        E: TopoDS_Edge
        C2DF: TopOpeBRepTool_C2DF
        factor: float

        Return
        -------
        gp_Vec2d

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_Tg2dApp(*args)

    @staticmethod
    def TgINSIDE(*args):
        r"""

        Parameters
        ----------
        v: TopoDS_Vertex
        E: TopoDS_Edge
        Tg: gp_Vec

        Return
        -------
        OvinE: int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_TgINSIDE(*args)

    @staticmethod
    def TggeomE(*args):
        r"""

        Parameters
        ----------
        par: float
        BC: BRepAdaptor_Curve
        Tg: gp_Vec

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        par: float
        E: TopoDS_Edge
        Tg: gp_Vec

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_TggeomE(*args)

    @staticmethod
    def TolP(*args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_TolP(*args)

    @staticmethod
    def TolUV(*args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face
        tol3d: float

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_TolUV(*args)

    @staticmethod
    def TrslUV(*args):
        r"""

        Parameters
        ----------
        t2d: gp_Vec2d
        C2DF: TopOpeBRepTool_C2DF

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_TrslUV(*args)

    @staticmethod
    def TrslUVModifE(*args):
        r"""

        Parameters
        ----------
        t2d: gp_Vec2d
        F: TopoDS_Face
        E: TopoDS_Edge

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_TrslUVModifE(*args)

    @staticmethod
    def UVF(*args):
        r"""

        Parameters
        ----------
        par: float
        C2DF: TopOpeBRepTool_C2DF

        Return
        -------
        gp_Pnt2d

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_UVF(*args)

    @staticmethod
    def UVISO(*args):
        r"""

        Parameters
        ----------
        PC: Geom2d_Curve
        d2d: gp_Dir2d
        o2d: gp_Pnt2d

        Return
        -------
        isou: bool
        isov: bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        C2DF: TopOpeBRepTool_C2DF
        d2d: gp_Dir2d
        o2d: gp_Pnt2d

        Return
        -------
        isou: bool
        isov: bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        E: TopoDS_Edge
        F: TopoDS_Face
        d2d: gp_Dir2d
        o2d: gp_Pnt2d

        Return
        -------
        isou: bool
        isov: bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_UVISO(*args)

    @staticmethod
    def Vertex(*args):
        r"""

        Parameters
        ----------
        Iv: int
        E: TopoDS_Edge

        Return
        -------
        TopoDS_Vertex

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_Vertex(*args)

    @staticmethod
    def Vertices(*args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge
        Vces: TopTools_Array1OfShape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_Vertices(*args)

    @staticmethod
    def WireToFace(*args):
        r"""

        Parameters
        ----------
        Fref: TopoDS_Face
        mapWlow: TopTools_DataMapOfShapeListOfShape
        lFs: TopTools_ListOfShape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_WireToFace(*args)

    @staticmethod
    def XX(*args):
        r"""

        Parameters
        ----------
        uv: gp_Pnt2d
        f: TopoDS_Face
        par: float
        e: TopoDS_Edge
        xx: gp_Dir

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_XX(*args)

    @staticmethod
    def minDUV(*args):
        r"""

        Parameters
        ----------
        F: TopoDS_Face

        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_minDUV(*args)

    @staticmethod
    def outUVbounds(*args):
        r"""

        Parameters
        ----------
        uv: gp_Pnt2d
        F: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_outUVbounds(*args)

    @staticmethod
    def stuvF(*args):
        r"""

        Parameters
        ----------
        uv: gp_Pnt2d
        F: TopoDS_Face

        Return
        -------
        onU: int
        onV: int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_stuvF(*args)

    @staticmethod
    def tryNgApp(*args):
        r"""

        Parameters
        ----------
        par: float
        E: TopoDS_Edge
        F: TopoDS_Face
        tola: float
        ng: gp_Dir

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_tryNgApp(*args)

    @staticmethod
    def tryOriEinF(*args):
        r"""

        Parameters
        ----------
        par: float
        E: TopoDS_Edge
        F: TopoDS_Face

        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_tryOriEinF(*args)

    @staticmethod
    def tryTg2dApp(*args):
        r"""

        Parameters
        ----------
        iv: int
        E: TopoDS_Edge
        C2DF: TopOpeBRepTool_C2DF
        factor: float

        Return
        -------
        gp_Vec2d

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_tryTg2dApp(*args)

    @staticmethod
    def uvApp(*args):
        r"""

        Parameters
        ----------
        f: TopoDS_Face
        e: TopoDS_Edge
        par: float
        eps: float
        uvapp: gp_Pnt2d

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_TOOL_uvApp(*args)

    __repr__ = _dumps_object


    def __init__(self):
        _TopOpeBRepTool.TopOpeBRepTool_TOOL_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_TOOL())
    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_TOOL

# Register TopOpeBRepTool_TOOL in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_TOOL_swigregister(TopOpeBRepTool_TOOL)
class TopOpeBRepTool_connexity(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        Key: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_connexity_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_connexity(*args))

    def AddItem(self, *args):
        r"""

        Parameters
        ----------
        OriKey: int
        Item: TopTools_ListOfShape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        OriKey: int
        Item: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_connexity_AddItem(self, *args)

    def AllItems(self, *args):
        r"""

        Parameters
        ----------
        Item: TopTools_ListOfShape

        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_connexity_AllItems(self, *args)

    def ChangeItem(self, *args):
        r"""

        Parameters
        ----------
        OriKey: int

        Return
        -------
        TopTools_ListOfShape

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_connexity_ChangeItem(self, *args)

    def IsFaulty(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_connexity_IsFaulty(self, *args)

    def IsInternal(self, *args):
        r"""

        Parameters
        ----------
        Item: TopTools_ListOfShape

        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_connexity_IsInternal(self, *args)

    def IsMultiple(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_connexity_IsMultiple(self, *args)

    def Item(self, *args):
        r"""

        Parameters
        ----------
        OriKey: int
        Item: TopTools_ListOfShape

        Return
        -------
        int

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_connexity_Item(self, *args)

    def Key(self, *args):
        r"""
        Return
        -------
        TopoDS_Shape

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_connexity_Key(self, *args)

    def RemoveItem(self, *args):
        r"""

        Parameters
        ----------
        OriKey: int
        Item: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        Parameters
        ----------
        Item: TopoDS_Shape

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_connexity_RemoveItem(self, *args)

    def SetKey(self, *args):
        r"""

        Parameters
        ----------
        Key: TopoDS_Shape

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_connexity_SetKey(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_connexity

# Register TopOpeBRepTool_connexity in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_connexity_swigregister(TopOpeBRepTool_connexity)
class TopOpeBRepTool_face(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_face_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_face(*args))

    def Ffinite(self, *args):
        r"""
        Return
        -------
        TopoDS_Face

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_face_Ffinite(self, *args)

    def Finite(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_face_Finite(self, *args)

    def Init(self, *args):
        r"""

        Parameters
        ----------
        W: TopoDS_Wire
        Fref: TopoDS_Face

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_face_Init(self, *args)

    def IsDone(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_face_IsDone(self, *args)

    def RealF(self, *args):
        r"""
        Return
        -------
        TopoDS_Face

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_face_RealF(self, *args)

    def W(self, *args):
        r"""
        Return
        -------
        TopoDS_Wire

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_face_W(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_face

# Register TopOpeBRepTool_face in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_face_swigregister(TopOpeBRepTool_face)
class TopOpeBRepTool_makeTransition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        _TopOpeBRepTool.TopOpeBRepTool_makeTransition_swiginit(self, _TopOpeBRepTool.new_TopOpeBRepTool_makeTransition(*args))

    def Getfactor(self, *args):
        r"""
        Return
        -------
        float

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_makeTransition_Getfactor(self, *args)

    def HasRest(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_makeTransition_HasRest(self, *args)

    def Initialize(self, *args):
        r"""

        Parameters
        ----------
        E: TopoDS_Edge
        pbef: float
        paft: float
        parE: float
        FS: TopoDS_Face
        uv: gp_Pnt2d
        factor: float

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_makeTransition_Initialize(self, *args)

    def IsT2d(self, *args):
        r"""
        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_makeTransition_IsT2d(self, *args)

    def MkT2donE(self, *args):
        r"""

        Parameters
        ----------
        stb: TopAbs_State
        sta: TopAbs_State

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_makeTransition_MkT2donE(self, *args)

    def MkT3dproj(self, *args):
        r"""

        Parameters
        ----------
        stb: TopAbs_State
        sta: TopAbs_State

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_makeTransition_MkT3dproj(self, *args)

    def MkT3onE(self, *args):
        r"""

        Parameters
        ----------
        stb: TopAbs_State
        sta: TopAbs_State

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_makeTransition_MkT3onE(self, *args)

    def MkTonE(self, *args):
        r"""

        Parameters
        ----------
        stb: TopAbs_State
        sta: TopAbs_State

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_makeTransition_MkTonE(self, *args)

    def SetRest(self, *args):
        r"""

        Parameters
        ----------
        ES: TopoDS_Edge
        parES: float

        Return
        -------
        bool

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_makeTransition_SetRest(self, *args)

    def Setfactor(self, *args):
        r"""

        Parameters
        ----------
        factor: float

        Return
        -------
        None

        Description
        -----------
        No available documentation.

        """
        return _TopOpeBRepTool.TopOpeBRepTool_makeTransition_Setfactor(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _TopOpeBRepTool.delete_TopOpeBRepTool_makeTransition

# Register TopOpeBRepTool_makeTransition in _TopOpeBRepTool:
_TopOpeBRepTool.TopOpeBRepTool_makeTransition_swigregister(TopOpeBRepTool_makeTransition)

@classnotwrapped
class TopOpeBRepTool_STATE:
	pass

@classnotwrapped
class TopOpeBRepTool_mkTondgE:
	pass





@deprecated
def topopebreptool_CorrectONUVISO(*args):
	return topopebreptool.CorrectONUVISO(*args)

@deprecated
def topopebreptool_MakeFaces(*args):
	return topopebreptool.MakeFaces(*args)

@deprecated
def topopebreptool_PurgeClosingEdges(*args):
	return topopebreptool.PurgeClosingEdges(*args)

@deprecated
def topopebreptool_PurgeClosingEdges(*args):
	return topopebreptool.PurgeClosingEdges(*args)

@deprecated
def topopebreptool_Regularize(*args):
	return topopebreptool.Regularize(*args)

@deprecated
def topopebreptool_RegularizeFace(*args):
	return topopebreptool.RegularizeFace(*args)

@deprecated
def topopebreptool_RegularizeShells(*args):
	return topopebreptool.RegularizeShells(*args)

@deprecated
def topopebreptool_RegularizeWires(*args):
	return topopebreptool.RegularizeWires(*args)

@deprecated
def TopOpeBRepTool_AncestorsTool_MakeAncestors(*args):
	return TopOpeBRepTool_AncestorsTool.MakeAncestors(*args)

@deprecated
def TopOpeBRepTool_BoxSort_MakeHABCOB(*args):
	return TopOpeBRepTool_BoxSort.MakeHABCOB(*args)

@deprecated
def TopOpeBRepTool_CurveTool_IsProjectable(*args):
	return TopOpeBRepTool_CurveTool.IsProjectable(*args)

@deprecated
def TopOpeBRepTool_CurveTool_MakeBSpline1fromPnt(*args):
	return TopOpeBRepTool_CurveTool.MakeBSpline1fromPnt(*args)

@deprecated
def TopOpeBRepTool_CurveTool_MakeBSpline1fromPnt2d(*args):
	return TopOpeBRepTool_CurveTool.MakeBSpline1fromPnt2d(*args)

@deprecated
def TopOpeBRepTool_CurveTool_MakePCurveOnFace(*args):
	return TopOpeBRepTool_CurveTool.MakePCurveOnFace(*args)

@deprecated
def TopOpeBRepTool_HBoxTool_ComputeBox(*args):
	return TopOpeBRepTool_HBoxTool.ComputeBox(*args)

@deprecated
def TopOpeBRepTool_HBoxTool_ComputeBoxOnVertices(*args):
	return TopOpeBRepTool_HBoxTool.ComputeBoxOnVertices(*args)

@deprecated
def TopOpeBRepTool_HBoxTool_DumpB(*args):
	return TopOpeBRepTool_HBoxTool.DumpB(*args)

@deprecated
def TopOpeBRepTool_REGUS_SplitF(*args):
	return TopOpeBRepTool_REGUS.SplitF(*args)

@deprecated
def TopOpeBRepTool_REGUS_WireToFace(*args):
	return TopOpeBRepTool_REGUS.WireToFace(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_AdjustOnPeriodic(*args):
	return TopOpeBRepTool_ShapeTool.AdjustOnPeriodic(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_BASISCURVE(*args):
	return TopOpeBRepTool_ShapeTool.BASISCURVE(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_BASISCURVE(*args):
	return TopOpeBRepTool_ShapeTool.BASISCURVE(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_BASISSURFACE(*args):
	return TopOpeBRepTool_ShapeTool.BASISSURFACE(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_BASISSURFACE(*args):
	return TopOpeBRepTool_ShapeTool.BASISSURFACE(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_Closed(*args):
	return TopOpeBRepTool_ShapeTool.Closed(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_CurvesSameOriented(*args):
	return TopOpeBRepTool_ShapeTool.CurvesSameOriented(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_EdgeData(*args):
	return TopOpeBRepTool_ShapeTool.EdgeData(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_EdgeData(*args):
	return TopOpeBRepTool_ShapeTool.EdgeData(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_EdgesSameOriented(*args):
	return TopOpeBRepTool_ShapeTool.EdgesSameOriented(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_FacesSameOriented(*args):
	return TopOpeBRepTool_ShapeTool.FacesSameOriented(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_PeriodizeParameter(*args):
	return TopOpeBRepTool_ShapeTool.PeriodizeParameter(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_Pnt(*args):
	return TopOpeBRepTool_ShapeTool.Pnt(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_Resolution3d(*args):
	return TopOpeBRepTool_ShapeTool.Resolution3d(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_Resolution3d(*args):
	return TopOpeBRepTool_ShapeTool.Resolution3d(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_Resolution3dU(*args):
	return TopOpeBRepTool_ShapeTool.Resolution3dU(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_Resolution3dV(*args):
	return TopOpeBRepTool_ShapeTool.Resolution3dV(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_ShapesSameOriented(*args):
	return TopOpeBRepTool_ShapeTool.ShapesSameOriented(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_SurfacesSameOriented(*args):
	return TopOpeBRepTool_ShapeTool.SurfacesSameOriented(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_Tolerance(*args):
	return TopOpeBRepTool_ShapeTool.Tolerance(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_UVBOUNDS(*args):
	return TopOpeBRepTool_ShapeTool.UVBOUNDS(*args)

@deprecated
def TopOpeBRepTool_ShapeTool_UVBOUNDS(*args):
	return TopOpeBRepTool_ShapeTool.UVBOUNDS(*args)

@deprecated
def TopOpeBRepTool_TOOL_ClosedE(*args):
	return TopOpeBRepTool_TOOL.ClosedE(*args)

@deprecated
def TopOpeBRepTool_TOOL_ClosedS(*args):
	return TopOpeBRepTool_TOOL.ClosedS(*args)

@deprecated
def TopOpeBRepTool_TOOL_CurvE(*args):
	return TopOpeBRepTool_TOOL.CurvE(*args)

@deprecated
def TopOpeBRepTool_TOOL_CurvF(*args):
	return TopOpeBRepTool_TOOL.CurvF(*args)

@deprecated
def TopOpeBRepTool_TOOL_EdgeONFace(*args):
	return TopOpeBRepTool_TOOL.EdgeONFace(*args)

@deprecated
def TopOpeBRepTool_TOOL_Getduv(*args):
	return TopOpeBRepTool_TOOL.Getduv(*args)

@deprecated
def TopOpeBRepTool_TOOL_Getstp3dF(*args):
	return TopOpeBRepTool_TOOL.Getstp3dF(*args)

@deprecated
def TopOpeBRepTool_TOOL_IsClosingE(*args):
	return TopOpeBRepTool_TOOL.IsClosingE(*args)

@deprecated
def TopOpeBRepTool_TOOL_IsClosingE(*args):
	return TopOpeBRepTool_TOOL.IsClosingE(*args)

@deprecated
def TopOpeBRepTool_TOOL_IsQuad(*args):
	return TopOpeBRepTool_TOOL.IsQuad(*args)

@deprecated
def TopOpeBRepTool_TOOL_IsQuad(*args):
	return TopOpeBRepTool_TOOL.IsQuad(*args)

@deprecated
def TopOpeBRepTool_TOOL_IsonCLO(*args):
	return TopOpeBRepTool_TOOL.IsonCLO(*args)

@deprecated
def TopOpeBRepTool_TOOL_IsonCLO(*args):
	return TopOpeBRepTool_TOOL.IsonCLO(*args)

@deprecated
def TopOpeBRepTool_TOOL_Matter(*args):
	return TopOpeBRepTool_TOOL.Matter(*args)

@deprecated
def TopOpeBRepTool_TOOL_Matter(*args):
	return TopOpeBRepTool_TOOL.Matter(*args)

@deprecated
def TopOpeBRepTool_TOOL_Matter(*args):
	return TopOpeBRepTool_TOOL.Matter(*args)

@deprecated
def TopOpeBRepTool_TOOL_Matter(*args):
	return TopOpeBRepTool_TOOL.Matter(*args)

@deprecated
def TopOpeBRepTool_TOOL_MatterKPtg(*args):
	return TopOpeBRepTool_TOOL.MatterKPtg(*args)

@deprecated
def TopOpeBRepTool_TOOL_MkShell(*args):
	return TopOpeBRepTool_TOOL.MkShell(*args)

@deprecated
def TopOpeBRepTool_TOOL_NgApp(*args):
	return TopOpeBRepTool_TOOL.NgApp(*args)

@deprecated
def TopOpeBRepTool_TOOL_NggeomF(*args):
	return TopOpeBRepTool_TOOL.NggeomF(*args)

@deprecated
def TopOpeBRepTool_TOOL_Nt(*args):
	return TopOpeBRepTool_TOOL.Nt(*args)

@deprecated
def TopOpeBRepTool_TOOL_OnBoundary(*args):
	return TopOpeBRepTool_TOOL.OnBoundary(*args)

@deprecated
def TopOpeBRepTool_TOOL_OriinSor(*args):
	return TopOpeBRepTool_TOOL.OriinSor(*args)

@deprecated
def TopOpeBRepTool_TOOL_OriinSorclosed(*args):
	return TopOpeBRepTool_TOOL.OriinSorclosed(*args)

@deprecated
def TopOpeBRepTool_TOOL_ParE(*args):
	return TopOpeBRepTool_TOOL.ParE(*args)

@deprecated
def TopOpeBRepTool_TOOL_ParE2d(*args):
	return TopOpeBRepTool_TOOL.ParE2d(*args)

@deprecated
def TopOpeBRepTool_TOOL_ParISO(*args):
	return TopOpeBRepTool_TOOL.ParISO(*args)

@deprecated
def TopOpeBRepTool_TOOL_Remove(*args):
	return TopOpeBRepTool_TOOL.Remove(*args)

@deprecated
def TopOpeBRepTool_TOOL_SplitE(*args):
	return TopOpeBRepTool_TOOL.SplitE(*args)

@deprecated
def TopOpeBRepTool_TOOL_Tg2d(*args):
	return TopOpeBRepTool_TOOL.Tg2d(*args)

@deprecated
def TopOpeBRepTool_TOOL_Tg2dApp(*args):
	return TopOpeBRepTool_TOOL.Tg2dApp(*args)

@deprecated
def TopOpeBRepTool_TOOL_TgINSIDE(*args):
	return TopOpeBRepTool_TOOL.TgINSIDE(*args)

@deprecated
def TopOpeBRepTool_TOOL_TggeomE(*args):
	return TopOpeBRepTool_TOOL.TggeomE(*args)

@deprecated
def TopOpeBRepTool_TOOL_TggeomE(*args):
	return TopOpeBRepTool_TOOL.TggeomE(*args)

@deprecated
def TopOpeBRepTool_TOOL_TolP(*args):
	return TopOpeBRepTool_TOOL.TolP(*args)

@deprecated
def TopOpeBRepTool_TOOL_TolUV(*args):
	return TopOpeBRepTool_TOOL.TolUV(*args)

@deprecated
def TopOpeBRepTool_TOOL_TrslUV(*args):
	return TopOpeBRepTool_TOOL.TrslUV(*args)

@deprecated
def TopOpeBRepTool_TOOL_TrslUVModifE(*args):
	return TopOpeBRepTool_TOOL.TrslUVModifE(*args)

@deprecated
def TopOpeBRepTool_TOOL_UVF(*args):
	return TopOpeBRepTool_TOOL.UVF(*args)

@deprecated
def TopOpeBRepTool_TOOL_UVISO(*args):
	return TopOpeBRepTool_TOOL.UVISO(*args)

@deprecated
def TopOpeBRepTool_TOOL_UVISO(*args):
	return TopOpeBRepTool_TOOL.UVISO(*args)

@deprecated
def TopOpeBRepTool_TOOL_UVISO(*args):
	return TopOpeBRepTool_TOOL.UVISO(*args)

@deprecated
def TopOpeBRepTool_TOOL_Vertex(*args):
	return TopOpeBRepTool_TOOL.Vertex(*args)

@deprecated
def TopOpeBRepTool_TOOL_Vertices(*args):
	return TopOpeBRepTool_TOOL.Vertices(*args)

@deprecated
def TopOpeBRepTool_TOOL_WireToFace(*args):
	return TopOpeBRepTool_TOOL.WireToFace(*args)

@deprecated
def TopOpeBRepTool_TOOL_XX(*args):
	return TopOpeBRepTool_TOOL.XX(*args)

@deprecated
def TopOpeBRepTool_TOOL_minDUV(*args):
	return TopOpeBRepTool_TOOL.minDUV(*args)

@deprecated
def TopOpeBRepTool_TOOL_outUVbounds(*args):
	return TopOpeBRepTool_TOOL.outUVbounds(*args)

@deprecated
def TopOpeBRepTool_TOOL_stuvF(*args):
	return TopOpeBRepTool_TOOL.stuvF(*args)

@deprecated
def TopOpeBRepTool_TOOL_tryNgApp(*args):
	return TopOpeBRepTool_TOOL.tryNgApp(*args)

@deprecated
def TopOpeBRepTool_TOOL_tryOriEinF(*args):
	return TopOpeBRepTool_TOOL.tryOriEinF(*args)

@deprecated
def TopOpeBRepTool_TOOL_tryTg2dApp(*args):
	return TopOpeBRepTool_TOOL.tryTg2dApp(*args)

@deprecated
def TopOpeBRepTool_TOOL_uvApp(*args):
	return TopOpeBRepTool_TOOL.uvApp(*args)



